# neatly

**NOTE: neatly is not yet functional**  
  
*neatly* is a package designed to facilitate the implementation of [NeuroEvolution of Augmenting Topologies (NEAT)](http://nn.cs.utexas.edu/downloads/papers/stanley.ec02.pdf) in Python.

## Installation
neatly can be installed with pip via:
```bash
pip install neatly
```

## Usage/Example
:construction: still under construction :construction:
```python
import neatly
```

## Contributing
To be completely honest, I don't know why anybody would want to contribute to this pile of hot garbage, and I don't really know how contributing works, but if you're interested email [me](mailto:seanrhee2024@u.northwestern.edu?subject=[Github]%20contributing%20to%20neatly).

## License
[MIT](https://choosealicense.com/licenses/mit/)